{% load i18n %}
{% load pymorphy_tags %}

<h3>По {{ title|inflect:"дт" }}</h3>
<ul>
{% for choice in choices %}
    <li{% if choice.selected %} class="selected"{% endif %}>
    <a href="{{ choice.query_string|iriencode }}">{{ choice.display }}</a></li>
{% endfor %}
</ul>
