{% extends "admin_extended:admin/base_site.html" %}
{% load ruadmin %}

{% block title %}{% extratrans 'title' 'caption' %}{% endblock %}
{% block branding %}<h1 id="site-name">{% extratrans 'branding' 'caption' %}</h1>{% endblock %}
