{% extends SETTING_ADMIN_TOOLS_USAGE|yesno:"dashboard:admin/app_index.html,admin:admin/app_index.html" %}
{% load ruadmin %}

{% block breadcrumbs %}
    <div class="breadcrumbs"><a href="../">{% extratrans 'home' 'caption' %}</a> &rsaquo; 
    {% for app in app_list %}
        {% extratrans app.name|capfirst %}
    {% endfor %}
    </div>
{% endblock %}