{% extends "admin:admin/change_form.html" %}
{% load admin_urls %}
{% load pymorphy_tags %}
{% load ruadmin %}

{% if not is_popup %}
    {% block breadcrumbs %}
    <div class="breadcrumbs">
        {% render_breadcrumbs opts.app_label %}
        &rsaquo; {% if has_change_permission %}<a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>{% else %}{{ opts.verbose_name_plural|capfirst }}{% endif %}
        &rsaquo; {% if add %}Добавить {{ opts.verbose_name|inflect:"вн" }}{% else %}{{ original|truncatewords:"18" }}{% endif %}
    </div>
    {% endblock %}
{% endif %}
