{% extends "admin:admin/change_list.html" %}
{% load admin_urls %}
{% load pymorphy_tags %}
{% load ruadmin %} 

{% if not is_popup %}
    {% block breadcrumbs %}
        <div class="breadcrumbs">
            {% render_breadcrumbs cl.opts.app_label %}
            &rsaquo; {{ cl.opts.verbose_name_plural|capfirst }}
        </div>
    {% endblock %}
{% endif %}

{% block object-tools %}
    {% if has_add_permission %}
        <ul class="object-tools">
        {% block object-tools-items %}
            <li>
                <a href="{% url cl.opts|admin_urlname:'add' %}{% if is_popup %}?_popup=1{% endif %}" class="addlink">
                    Добавить {{ cl.opts.verbose_name|inflect:"вн" }}
                </a>
            </li>
        {% endblock %}
        </ul>
    {% endif %}
{% endblock %}
