{% load admin_urls %}
{% load ruadmin %}

<a href="{% url 'admin:index' %}">{% extratrans 'home' 'caption' %}</a>
&rsaquo; <a href="{% url 'admin:app_list' app_label=app_label %}">{% extratrans app_label|capfirst|escape %}</a>
